@@ -28,7 +28,7 @@ class TonPlayApi(Api):
 
     # Games
 
-    from tonplay.methods._game import make_payout_request
+    from tonplay.methods._game import make_withdraw_request
 
     # Auth
 
