@@ -1,10 +1,10 @@
 
 
-def make_payout_request(self, payout_id):
+def make_withdraw_request(self, withdrawal_id):
     """
         Make payout request
 
-        POST /gamecenter/v1/payout
+        POST /gamecenter/v1/withdraw
 
         How it works:
 
@@ -20,9 +20,9 @@ def make_payout_request(self, payout_id):
         - if your API answer is OK than TONPLAY will send requested TON amount to selected address
 
         Args:
-            payout_id (str) : payout_id from your system in any format
+            withdrawal_id (str) : withdrawal_id from your system in any format
     """
 
-    url_path = f"/gamecenter/v1/payout"
-    payload = {"payoutId": payout_id}
+    url_path = f"/gamecenter/v1/withdraw"
+    payload = {"withdrawalId": withdrawal_id}
     return self.send_request("POST", url_path, payload=payload)
